@@ -77,14 +77,14 @@
       stop("Probabilities in 'init.estim' must be between [0, 1]")
     }
     
-    if (!((sum(init.estim) >= 1 - .Machine$double.eps) | (sum(init.estim) <= 1 + .Machine$double.eps))) {
+    if (!((sum(init.estim) >= 1 - sqrt(.Machine$double.eps)) | (sum(init.estim) <= 1 + sqrt(.Machine$double.eps)))) {
       stop("The sum of 'init.estim' is not equal to one")
     }
     
     init <- init.estim
   }
   
-  init <- init / sum(init)
+  init <- as.vector(init / sum(init))
   
   estimate <-
     smmnonparametric(
