@@ -164,7 +164,7 @@ smmparametric <- function(states, init, ptrans, type.sojourn = c("fij", "fi", "f
     stop("Probabilities in 'init' must be between [0, 1]")
   }
   
-  if (!((sum(init) >= 1 - .Machine$double.eps) | (sum(init) <= 1 + .Machine$double.eps))) {
+  if (!((sum(init) >= 1 - sqrt(.Machine$double.eps)) & (sum(init) <= 1 + sqrt(.Machine$double.eps)))) {
     stop("The sum of 'init' is not equal to one")
   }
   
@@ -188,7 +188,7 @@ smmparametric <- function(states, init, ptrans, type.sojourn = c("fij", "fi", "f
     stop("All the diagonal elements of 'ptrans' must be equal to 0 since transitions to the same state are not allowed")
   }
   
-  if (!all((apply(ptrans, 1, sum) >= 1 - .Machine$double.eps) | (apply(ptrans, 1, sum) <= 1 + .Machine$double.eps))) {
+  if (!all((apply(ptrans, 1, sum) >= 1 - sqrt(.Machine$double.eps)) & (apply(ptrans, 1, sum) <= 1 + sqrt(.Machine$double.eps)))) {
     stop("'ptrans' is not a stochastic matrix (column sums accross rows must be equal to one for each row)")
   }
   
